// src/minio.ts
import { Client } from "minio";

// src/helpers/client-options.schema.ts
import { UrlSchema } from "@settlemint/sdk-utils/validation";
import { z } from "zod";
var ClientOptionsSchema = z.object({
  /** The URL of the MinIO instance to connect to */
  instance: UrlSchema
});
var ServerClientOptionsSchema = z.object({
  /** The URL of the MinIO instance to connect to */
  instance: UrlSchema,
  /** The MinIO access key used to authenticate with the MinIO server */
  accessKey: z.string(),
  /** The MinIO secret key used to authenticate with the MinIO server */
  secretKey: z.string()
});

// src/helpers/runtime.ts
function ensureServer() {
  if (typeof window !== "undefined") {
    throw new Error("This function can only be called on the server.");
  }
}

// src/helpers/schema.ts
import { z as z2 } from "zod";
var t = {
  String: (options = {}) => {
    let schema = z2.string();
    if (options.format === "date-time") {
      schema = schema.datetime();
    } else if (options.format === "uri") {
      schema = schema.url();
    }
    return schema;
  },
  Number: () => {
    return z2.number();
  },
  Boolean: () => {
    return z2.boolean();
  },
  Object: (shape, options = {}) => {
    return z2.object(shape);
  },
  Array: (items) => {
    return z2.array(items);
  },
  Optional: (schema) => {
    return schema.optional();
  }
};
function validate(schema, value) {
  return schema.parse(value);
}
var FileMetadataSchema = t.Object(
  {
    id: t.String(),
    name: t.String(),
    contentType: t.String(),
    size: t.Number(),
    uploadedAt: t.String({ format: "date-time" }),
    etag: t.String(),
    url: t.Optional(t.String({ format: "uri" }))
  },
  { $id: "FileMetadata" }
);

// src/minio.ts
function createServerMinioClient(options) {
  ensureServer();
  const validatedOptions = validate(ServerClientOptionsSchema, options);
  const url = new URL(validatedOptions.instance);
  return {
    client: new Client({
      endPoint: url.hostname,
      accessKey: validatedOptions.accessKey,
      secretKey: validatedOptions.secretKey,
      useSSL: url.protocol !== "http:",
      port: url.port ? Number(url.port) : void 0,
      region: "eu-central-1"
    })
  };
}
export {
  createServerMinioClient
};
//# sourceMappingURL=minio.mjs.map